pub enum ExecutionMode {
PrepareNone,
PrepareBuild,
PrepareProbe,
Speculative(usize),
}Expand description
Execution mode for spatial join operations, controlling prepared geometry usage.
Prepared geometries are pre-processed spatial objects that can significantly improve performance for spatial predicate evaluation when the same geometry is used multiple times in comparisons.
The choice of execution mode depends on the specific characteristics of your spatial join workload, as well as the spatial relation predicate between the two tables. Some of the spatial relation computations cannot be accelerated by prepared geometries at all (for example, ST_Touches, ST_Crosses, ST_DWithin).
Variants
PrepareNone
Don’t use prepared geometries for spatial predicate evaluation.
PrepareBuild
Create prepared geometries for the build side (left/smaller table).
PrepareProbe
Create prepared geometries for the probe side (right/larger table).
Speculative(usize)
Automatically choose the best execution mode based on the characteristics of first few geometries on the probe side.
Implementations