SpatialJoinExec

Struct SpatialJoinExec 

pub struct SpatialJoinExec {
    pub left: Arc<dyn ExecutionPlan>,
    pub right: Arc<dyn ExecutionPlan>,
    pub on: SpatialPredicate,
    pub filter: Option<JoinFilter>,
    pub join_type: JoinType,
    pub metrics: ExecutionPlanMetricsSet,
    /* private fields */
}
Physical execution plan for performing spatial joins between two tables. It uses a spatial index to speed up the join operation.

Algorithm Overview

The spatial join execution follows a hash-join-like pattern:

  1. Build Phase: The left (smaller) table geometries are indexed using a spatial index
  2. Probe Phase: Each geometry from the right table is used to query the spatial index
  3. Refinement: Candidate pairs from the index are refined using exact spatial predicates
  4. Output: Matching pairs are combined according to the specified join type

Fields

left: Arc<dyn ExecutionPlan>

left (build) side which gets hashed

right: Arc<dyn ExecutionPlan>

right (probe) side which are filtered by the hash table

on: SpatialPredicate

Primary spatial join condition (the expression in the ON clause of the join)

filter: Option<JoinFilter>

Additional filters which are applied while finding matching rows. It could contain part of the ON clause, or expressions in the WHERE clause.

join_type: JoinType

How the join is performed (OUTER, INNER, etc)

metrics: ExecutionPlanMetricsSet

Metrics for tracking execution statistics (public for wrapper implementations)

Implementations

Source

impl SpatialJoinExec

pub fn try_new( left: Arc<dyn ExecutionPlan>, right: Arc<dyn ExecutionPlan>, on: SpatialPredicate, filter: Option<JoinFilter>, join_type: &JoinType, projection: Option<Vec<usize>>, options: &SpatialJoinOptions, ) -> Result<Self>

Try to create a new SpatialJoinExec

pub fn try_new_internal( left: Arc<dyn ExecutionPlan>, right: Arc<dyn ExecutionPlan>, on: SpatialPredicate, filter: Option<JoinFilter>, join_type: &JoinType, projection: Option<Vec<usize>>, seed: u64, ) -> Result<Self>

Create a new SpatialJoinExec with additional options

pub fn join_type(&self) -> &JoinType

How the join is performed

pub fn contains_projection(&self) -> bool

Does this join has a projection on the joined columns

pub fn swap_inputs(&self) -> Result<Arc<dyn ExecutionPlan>>

Returns a new ExecutionPlan that runs NestedLoopsJoins with the left and right inputs swapped.

Notes:

This function should be called BEFORE inserting any repartitioning operators on the join’s children. Check [super::HashJoinExec::swap_inputs] for more details.

pub fn with_projection(&self, projection: Option<Vec<usize>>) -> Result<Self>