EvaluatedGeometryArray

Struct EvaluatedGeometryArray 

pub struct EvaluatedGeometryArray {
    pub sedona_type: SedonaType,
    pub geometry_array: ArrayRef,
    pub rects: Vec<Option<Rect<f32>>>,
    pub distance: Option<ColumnarValue>,
    /* private fields */
}
Result of evaluating a geometry batch.

Fields

sedona_type: SedonaType

Type of geometry_array

geometry_array: ArrayRef

The array of geometries produced by evaluating the geometry expression.

rects: Vec<Option<Rect<f32>>>

The rects of the geometries in the geometry array. The length of this array is equal to the number of geometries. The rects will be None for empty or null geometries.

distance: Option<ColumnarValue>

The distance value produced by evaluating the distance expression.

Implementations

Source

impl EvaluatedGeometryArray

pub fn try_new( geometry_array: ArrayRef, sedona_type: &SedonaType, ) -> Result<Self>

pub fn wkbs(&self) -> &Vec<Option<Wkb<'_>>>

Get the WKBs of the geometries in the geometry array.

pub fn in_mem_size(&self) -> Result<usize>