pub enum PartitionedSide {
BuildSide,
ProbeSide,
}Expand description
Indicates for which side of the spatial join the partitioning is being performed. Different methods should be used for the build side and probe side.
Variants
BuildSide
Invoke SpatialPartitioner::partition_no_multi for partitioning
ProbeSide
Invoke SpatialPartitioner::partition for partitioning