pub enum SpatialPredicate {
Distance(DistancePredicate),
Relation(RelationPredicate),
KNearestNeighbors(KNNPredicate),
}Expand description
Spatial predicate is the join condition of a spatial join. It can be a distance predicate, a relation predicate, or a KNN predicate.
Variants