pub struct DistancePredicate {
pub left: Arc<dyn PhysicalExpr>,
pub right: Arc<dyn PhysicalExpr>,
pub distance: Arc<dyn PhysicalExpr>,
pub distance_side: JoinSide,
}Expand description
Distance-based spatial join predicate.
This predicate represents a spatial join condition based on distance between geometries. It is used to find pairs of geometries from left and right tables where the distance between them is less than a specified threshold.
Example SQL
SELECT * FROM left_table l JOIN right_table r
ON ST_Distance(l.geom, r.geom) < 100.0Fields
left- Expression to evaluate the left side geometryright- Expression to evaluate the right side geometrydistance- Expression to evaluate the distance thresholddistance_side- Which side the distance expression belongs to (for column references)
Fields
left: Arc<dyn PhysicalExpr>The expression for evaluating the geometry value on the left side. The expression should be evaluated directly on the left side batches.
right: Arc<dyn PhysicalExpr>The expression for evaluating the geometry value on the right side. The expression should be evaluated directly on the right side batches.
distance: Arc<dyn PhysicalExpr>The expression for evaluating the distance value. The expression should be evaluated directly on the left or right side batches according to distance_side.
distance_side: JoinSideThe side of the distance expression. It could be JoinSide::None if the distance expression is not a column reference. The most common case is that the distance expression is a literal value.
Implementations
Sourceimpl DistancePredicate
impl DistancePredicate
Sourcepub fn new(
left: Arc<dyn PhysicalExpr>,
right: Arc<dyn PhysicalExpr>,
distance: Arc<dyn PhysicalExpr>,
distance_side: JoinSide,
) -> Self
pub fn new( left: Arc<dyn PhysicalExpr>, right: Arc<dyn PhysicalExpr>, distance: Arc<dyn PhysicalExpr>, distance_side: JoinSide, ) -> Self
Creates a new distance predicate.
Arguments
left- Expression for the left side geometryright- Expression for the right side geometrydistance- Expression for the distance thresholddistance_side- Which side (Left, Right, or None) the distance expression belongs to