pub struct SpatialJoinDebugOptions {
pub num_spatial_partitions: NumSpatialPartitionsConfig,
pub memory_for_intermittent_usage: Option<usize>,
pub force_spill: bool,
pub random_seed: Option<u64>,
}Expand description
Configurations for debugging or testing spatial join
Fields
num_spatial_partitions: NumSpatialPartitionsConfigNumber of spatial partitions to use for spatial join
memory_for_intermittent_usage: Option<usize>The amount of memory for intermittent usage such as spatially repartitioning the data
force_spill: boolForce spilling while collecting the build side or not
random_seed: Option<u64>Seed for random processes in the spatial join for testing purpose