pub struct EvaluatedGeometryArray {
pub sedona_type: SedonaType,
pub geometry_array: ArrayRef,
pub rects: Vec<Option<Rect<f32>>>,
pub distance: Option<ColumnarValue>,
/* private fields */
}Expand description
Result of evaluating a geometry batch.
Fields
sedona_type: SedonaTypeType of geometry_array
geometry_array: ArrayRefThe array of geometries produced by evaluating the geometry expression.
rects: Vec<Option<Rect<f32>>>The rects of the geometries in the geometry array. The length of this array is equal to the number of geometries. The rects will be None for empty or null geometries.
distance: Option<ColumnarValue>The distance value produced by evaluating the distance expression.
Implementations