SpatialPartition

Enum SpatialPartition 

pub enum SpatialPartition {
    Regular(u32),
    None,
    Multi,
}
Spatial partitioning is different from traditional data partitioning such as hash partitioning. There is no perfect spatial partitioner that can partition spatial objects with extents (linestrings, polygons, etc.) into disjoint partitions without overlaps. Therefore, a spatial partitioner usually defines a set of spatial partitions (e.g., grid cells), and assigns each spatial object to one or more partitions based on its spatial extent. The spatial partitioner for our out-of-core spatial join follows a similar, but a bit different approach:

  1. It defines a fixed number of regular spatial partitions (e.g., grid cells), just like traditional spatial partitioners.
  2. It defines a None partition for spatial objects that does not intersect with any of the partitioning grids.
  3. It defines a Multi partition for spatial objects that intersect with multiple regular partitions.

The partitioning result can be one of the following:

  • Assigned to one of the regular partitions (if it intersects with exactly one regular partition).
  • Assigned to the None partition (if it does not intersect with any regular partition).
  • Assigned to the Multi partition (if it intersects with multiple regular partitions).

This spatial partitioning scheme assigns one and only one partition to each spatial object, which simplifies the partitioning logic for out-of-core spatial join. The partitioner will be designed to produce only Regular partitions for indexed objects, and may produce None and Multi partitions for probe objects, depending on their spatial extents.

Variants



Regular(u32)



None



Multi