pub struct RelationPredicate {
pub left: Arc<dyn PhysicalExpr>,
pub right: Arc<dyn PhysicalExpr>,
pub relation_type: SpatialRelationType,
}Expand description
Spatial relation predicate for topological relationships.
This predicate represents a spatial join condition based on topological relationships between geometries, such as intersects, contains, within, etc. It follows the DE-9IM (Dimensionally Extended 9-Intersection Model) spatial relations.
Example SQL
SELECT * FROM buildings b JOIN parcels p
ON ST_Intersects(b.geometry, p.geometry)Supported Relations
Intersects- Geometries share at least one pointContains- Left geometry contains the right geometryWithin- Left geometry is within the right geometryCovers- Left geometry covers the right geometryCoveredBy- Left geometry is covered by the right geometryTouches- Geometries touch at their boundariesCrosses- Geometries cross each otherOverlaps- Geometries overlapEquals- Geometries are spatially equal
Fields
left: Arc<dyn PhysicalExpr>The expression for evaluating the geometry value on the left side. The expression should be evaluated directly on the left side batches.
right: Arc<dyn PhysicalExpr>The expression for evaluating the geometry value on the right side. The expression should be evaluated directly on the right side batches.
relation_type: SpatialRelationTypeThe spatial relation type.
Implementations
Sourceimpl RelationPredicate
impl RelationPredicate
Sourcepub fn new(
left: Arc<dyn PhysicalExpr>,
right: Arc<dyn PhysicalExpr>,
relation_type: SpatialRelationType,
) -> Self
pub fn new( left: Arc<dyn PhysicalExpr>, right: Arc<dyn PhysicalExpr>, relation_type: SpatialRelationType, ) -> Self
Creates a new spatial relation predicate.
Arguments
left- Expression for the left side geometryright- Expression for the right side geometryrelation_type- The type of spatial relationship to test